*-----------------------------------------
*--   Set of procedures to work with    --
*-- Measurement Units Equivalents Form  --
*--       1996-2004 ARPA Software      --
*-----------------------------------------

#INCLUDE MEASURE.H

*-----------------------------------------------
*-- Activates Measurement Units Equivalents Form
*-----------------------------------------------
PROCEDURE SHOWMEASURE()

  IF TYPE('_screen.ActiveForm') = 'O' ;
       AND _screen.ActiveForm.WindowType = 1 && Modal - Go away
    = MsgBeep(-1)														 && MessageBeep IN Win32API
    RETURN
  ENDIF

  IF TYPE('g_MEASURE_Form') = 'U'
    PUBLIC g_MEASURE_Form
    g_MEASURE_Form= NULL
  ENDIF

  IF NOT WEXIST("Measurement_Unit_Equivalents")
    && Change current directory to the working...
    CD (gcHomePath)	&& public variable, see Main.prg
    DO FORM Measure NAME g_MEASURE_Form LINKED
  ELSE
    ACTIVATE WINDOW "Measurement_Unit_Equivalents"
  ENDIF

ENDPROC

*----------------------------------------------------
*-- Shows value in Measurement Units Equivalents Form
*----------------------------------------------------
PROCEDURE MEASURE()
  LPARAMETERS nValue, cType

	IF TYPE('g_MEASURE_Form') = 'O' AND ;
   !ISNULL(g_MEASURE_Form)
    g_MEASURE_Form.SetParam(nValue, cType)
  ENDIF

ENDPROC

*-------------------------------------------
*-- Hides Measurement Units Equivalents Form
*-------------------------------------------
PROCEDURE HIDEMEASURE()

  IF TYPE('_screen.ActiveForm') = 'O' ;
       AND _screen.ActiveForm.WindowType = 1 && Modal - Go away
    = MsgBeep(-1)														 && MessageBeep IN Win32API
    RETURN
  ENDIF
  
  IF TYPE('g_MEASURE_Form') = 'O' AND ;
   !ISNULL(g_MEASURE_Form)  
    g_MEASURE_Form = NULL
  ENDIF

ENDPROC

*-----------------------
*-- Activates calculator
*-----------------------
PROCEDURE SHOWCALCULATOR()

  IF TYPE('_screen.ActiveForm') = 'O' ;
       AND _screen.ActiveForm.WindowType = 1 && Modal - Go away
    = MsgBeep(-1)														 && MessageBeep IN Win32API
    RETURN
  ENDIF

  IF NOT WEXIST("Calculator")
    ACTIVATE WINDOW Calculator
  ELSE
    SHOW WINDOW Calculator
  ENDIF

ENDPROC

*-------------------------------------------------
*-- Returns string corresponding to cMeasure class
*-------------------------------------------------
FUNCTION GETMEASCLASS(cMeasure)

	IF USED("MEAS_CLS") AND ;
   ( MEAS_CLS.UID_CLASS == cMeasure ;
  OR SEEK(cMeasure, "MEAS_CLS", "UID_CLASS") )
    RETURN ALLTRIM(MEAS_CLS.NAME)
  ELSE
    RETURN ""
  ENDIF

ENDFUNC

*-----------------------------------------------------
*-- Returns string corresponding to cUnit measure unit
*-----------------------------------------------------
FUNCTION GETMEASUNIT(cUnit)

	IF USED("MEAS_FLD") AND ;
   ( MEAS_FLD.UID_FLD == cUnit ;
  OR SEEK(cUnit, "MEAS_FLD", "PK_FLD") )
    RETURN ALLTRIM(MEAS_FLD.NAME)
  ELSE
    RETURN ""
  ENDIF

ENDFUNC

*-----------------------------------------------------------------
*-- Returns abbreviated string corresponding to cUnit measure unit
*-----------------------------------------------------------------
FUNCTION GETMEASABBR(cUnit)

	IF USED("MEAS_FLD") AND ;
   ( MEAS_FLD.UID_FLD == cUnit ;
  OR SEEK(cUnit, "MEAS_FLD", "PK_FLD") )
    RETURN MEAS_FLD.ABBR
  ELSE
    RETURN ""
  ENDIF

ENDFUNC

*---------------------------------------------------------
*-- Convert the value N from measure unit cUnit1 to cUnit2
*---------------------------------------------------------
FUNCTION CONVMEASURE()
  LPARAMETERS cUnit1, cUnit2, N
  
  IF cUnit1 == cUnit2
    RETURN N
  ENDIF
  
	IF USED("MEAS_CVT") AND ;
   ( MEAS_CVT.FROM_FLD + MEAS_CVT.TO_FLD == cUnit1 + cUnit2 ;
  OR SEEK(cUnit1 + cUnit2, "MEAS_CVT", "PK_FLDS") )
    RETURN EVAL(MEAS_CVT.FORMULA)
  ELSE
    RETURN 0
  ENDIF
  
ENDFUNC

*------------------------------------------------------------------------
*-- Transform numeric value to string, using fixed or scientific notation
*------------------------------------------------------------------------
FUNCTION STRNUM()
	LPARAMETERS nValue, nSize
	LOCAL cBuf, cM, cE, cS, c
	LOCAL i, j, n

	IF nValue = 0
	  RETURN '0'
	ENDIF

	IF PARAMETERS() < 2 OR nSize > 20
	  nSize = 20
	ELSE
	  IF nSize < 8
	    nSize = 8
	  ENDIF
	ENDIF

	cBuf = ALLT(TRANS(nValue, "@^"))
	i    = AT('E', cBuf)
	j    = AT('.', cBuf) + 1

	IF nValue < 0
	  nSize = nSize - 1
	  cS    = '-'
	  c     = IIF(j = 3, '0', SUBS(cBuf, 2, 1))
	ELSE
	  cS    = ''
	  c     = IIF(j = 2, '0', LEFT(cBuf, 1))
	ENDIF

	n = i - j

	IF c = '0'
	  IF n > 14
	    n = 14
	  ENDIF
	ELSE
	  IF n > 13
	    n = 13
	  ENDIF
	ENDIF

	cM = SUBS(cBuf, j, n)
	cE = SUBS(cBuf, i+1)
	j  = n

	DO WHILE SUBS(cM, n, 1) = '0'
	  n = n - 1

	  IF n = 0
	    IF c = '0'
	      RETURN '0'
	    ELSE
	      cM = ''
	      EXIT
	    ENDIF
	  ENDIF
	ENDDO

	IF n > 0 AND n < j
	  cM = LEFT(cM, n)
	ENDIF

	j = INT(VAL(cE))

	IF c <> '0'
	  cM = c + cM
	  j  = j + 1
	  n  = n + 1
	ENDIF

	i = nSize - 5              && .E+00

	IF j < 0                   && Value less than 0.1
	  IF n - j > nSize - 2
	    IF n > i
	      cM = LEFT(STR(ROUND(VAL(cM), i - n), n), i)
	    ELSE
	      IF n < 2
	        cM = cM + '0'
	        n  = n + 1
	      ENDIF
	    ENDIF

	    j    = 1 - j
	    cE   = "E-" + IIF(j < 10, '0' + STR(j, 1), STR(j, 2))
	    cBuf = cS + LEFT(cM, 1) + '.' + SUBS(cM, 2) + cE
	  ELSE
	    cBuf = cS + "0." + REPL('0', -j) + cM
	  ENDIF
	ELSE
	  IF n < j                 && Value is integer
	    IF j > nSize
	      IF n > i
	        cM = LEFT(STR(ROUND(VAL(cM), i - n), n), i)
	      ENDIF

	      j    = j - 1
	      cE   = "E+" + IIF(j < 10, '0' + STR(j, 1), STR(j, 2))
	      cBuf = cS + LEFT(cM, 1) + '.' + SUBS(cM, 2) + cE
	    ELSE
	      cBuf = cS + cM + REPL('0', j - n)
	    ENDIF
	  ELSE                     && Value between 0.1 and 0.999..
	    IF n + IIF(j = 0, 2, 1) > nSize
	      IF n > i
	        cM = LEFT(STR(ROUND(VAL(cM), i - n), n), i)
	      ENDIF

	      IF j = 0
	        cE = "E-01"
	      ELSE
	        j    = j - 1
	        cE   = "E+" + IIF(j < 10, '0' + STR(j, 1), STR(j, 2))
	      ENDIF

	      cBuf = cS + LEFT(cM, 1) + '.' + SUBS(cM, 2) + cE
	    ELSE
	      IF n = j
	        cBuf = cS + cM
	      ELSE
	        IF j > 0
	          cBuf = cS + LEFT(cM, j) + '.' + SUBS(cM, j+1)
	        ELSE
	          cBuf = cS + "0." + cM
	        ENDIF
	      ENDIF
	    ENDIF
	  ENDIF
	ENDIF

	RETURN cBuf

ENDFUNC
