***** Table setup for MEAS_CLS *****
CREATE TABLE (cPath + 'MEAS_CLS.DBF') NAME 'MEAS_CLS' ( ;
  UID_CLASS C(2), ;
  NAME      C(64), ;
  UID_PAG1  C(2), ;
  UID_PAG2  C(2), ;
  UID_PAG3  C(2), ;
  UID_PAG4  C(2), ;
  REMARK    M     )

***** Create each index for MEAS_TIT *****
ALTER TABLE 'MEAS_CLS' ADD PRIMARY KEY UID_CLASS TAG PK

***** Change properties (if any) for MEAS_CLS *****
= DBSETPROP( "MEAS_CLS.UID_CLASS", "Field", "Comment", "Unit Class Id" )
= DBSETPROP( "MEAS_CLS.NAME", "Field", "Comment", "Unit Class Name" )
= DBSETPROP( "MEAS_CLS.UID_PAG1", "Field", "Comment", "UID of 1-st title page for this class" )
= DBSETPROP( "MEAS_CLS.UID_PAG2", "Field", "Comment", "UID of 2-nd title page for this class" )
= DBSETPROP( "MEAS_CLS.UID_PAG3", "Field", "Comment", "UID of 3-rd title page for this class" )
= DBSETPROP( "MEAS_CLS.UID_PAG4", "Field", "Comment", "UID of 4-th title page for this class" )
= DBSETPROP( "MEAS_CLS", "Table", "Comment", "Measurement Unit Classes")
APPEND FROM (cHome + 'MEAS_CLS.DBF')
USE

***** Table setup for MEAS_CVT *****
CREATE TABLE (cPath + 'MEAS_CVT.DBF') NAME 'MEAS_CVT' ( ;
  FROM_FLD C(3), ;
  TO_FLD   C(3), ;
  FORMULA  C(40) )

***** Create each index for MEAS_CVT *****
ALTER TABLE 'MEAS_CVT' ADD PRIMARY KEY FROM_FLD+TO_FLD TAG PK_FLDS

***** Change properties (if any) for MEAS_CVT *****
= DBSETPROP( "MEAS_CVT.FROM_FLD", "Field", "Comment", "From field" )
= DBSETPROP( "MEAS_CVT.TO_FLD", "Field", "Comment", "To field" )
= DBSETPROP( "MEAS_CVT.FORMULA", "Field", "Comment", "Formula" )
= DBSETPROP( "MEAS_CVT", "Table", "Comment", "Measurement Convertion Formulae")
APPEND FROM (cHome + 'MEAS_CVT.DBF')
USE

***** Table setup for MEAS_FLD *****
CREATE TABLE (cPath + 'MEAS_FLD.DBF') NAME 'MEAS_FLD' ( ;
  UID_FLD   C(3), ;
  UID_CLASS C(2), ;
  NAME      C(64), ;
  ABBR      C(12), ;
  LABEL     C(64), ;
  KEY       C(3) )

***** Create each index for MEAS_FLD *****
INDEX ON UID_CLASS TAG UID_CLASS
ALTER TABLE 'MEAS_FLD' ADD PRIMARY KEY UID_FLD TAG PK_FLD
ALTER TABLE 'MEAS_FLD' ADD UNIQUE UPPER(NAME) TAG NAME

***** Change properties (if any) for MEAS_FLD *****
= DBSETPROP( "MEAS_FLD.UID_FLD", "Field", "Comment", "UID of unit" )
= DBSETPROP( "MEAS_FLD.UID_CLASS", "Field", "Comment", "UID of the class (see MEAS_CLS)" )
= DBSETPROP( "MEAS_FLD.NAME", "Field", "Comment", "Name" )
= DBSETPROP( "MEAS_FLD.ABBR", "Field", "Comment", "Abbreviated name (ANSI codepage)" )
= DBSETPROP( "MEAS_FLD.LABEL", "Field", "Comment", "Label (to show in labels)" )
= DBSETPROP( "MEAS_FLD.KEY", "Field", "Comment", "Accelerator key" )
= DBSETPROP( "MEAS_FLD", "Table", "Comment", "Measurement Unit Types")
APPEND FROM (cHome + 'MEAS_FLD.DBF')
USE

***** Table setup for MEAS_TIT *****
CREATE TABLE (cPath + 'MEAS_TIT.DBF') NAME 'MEAS_TIT' ( ;
  UID_PAGE   C(2), ;
  UID_CLASS  C(2), ;
  BITMAP     G, ;
  BITMAP24K  G, ;
  BITMAP_XP  G, ;
  FLD_SHRINK C(1), ;
  FLD_EXTEND C(1), ;
  LABEL      C(64) )

***** Create each index for MEAS_TIT *****
ALTER TABLE 'MEAS_TIT' ADD PRIMARY KEY UID_PAGE TAG UID_PAGE

***** Change properties (if any) for MEAS_TIT *****
= DBSETPROP( "MEAS_TIT.UID_PAGE", "Field", "Comment", "UID of title page" )
= DBSETPROP( "MEAS_TIT.UID_CLASS", "Field", "Comment", "UID of class see MEAS_CLS)" )
= DBSETPROP( "MEAS_TIT.BITMAP", "Field", "Comment", "OLE" )
= DBSETPROP( "MEAS_TIT.FLD_SHRINK", "Field", "Comment", "Last visible field in the shrink mode" )
= DBSETPROP( "MEAS_TIT.FLD_EXTEND", "Field", "Comment", "Last visible field in the extended mode" )
= DBSETPROP( "MEAS_TIT.LABEL", "Field", "Comment", "Label (to show in combobox)" )
= DBSETPROP( "MEAS_TIT", "Table", "Comment", "Measurement Title Descriptions")
APPEND FROM (cHome + 'MEAS_TIT.DBF')
USE

***** Table setup for MEAS_TRF *****
CREATE TABLE (cPath + 'MEAS_TRF.DBF') NAME 'MEAS_TRF' ( ;
  TIT_FROM C(2), ;
  TIT_TO   C(2), ;
  FLD_FROM C(1), ;
  FLD_TO   C(1), ;
  FORMULA  C(40) )

***** Create each index for MEAS_TRF *****
ALTER TABLE 'MEAS_TRF' ADD PRIMARY KEY TIT_FROM+TIT_TO TAG PK_TRF

***** Change properties (if any) for MEAS_TRF *****
= DBSETPROP( "MEAS_TRF.TIT_FROM", "Field", "Comment", "from Title" )
= DBSETPROP( "MEAS_TRF.TIT_TO", "Field", "Comment", "to Title" )
= DBSETPROP( "MEAS_TRF.FLD_FROM", "Field", "Comment", "from Field" )
= DBSETPROP( "MEAS_TRF.FLD_TO", "Field", "Comment", "to Field" )
= DBSETPROP( "MEAS_TRF.FORMULA", "Field", "Comment", "Formula" )
= DBSETPROP( "MEAS_TRF", "Table", "Comment", "Measurement Page Transfer")
APPEND FROM (cHome + 'MEAS_TRF.DBF')
USE
